@@ -7,7 +7,8 @@ from webrtc_streaming.autogen import (
 )
 
 
-def negotiate(ip_server="localhost:50051", sdp=None, type_=None):
+def negotiate(ip_server=None, sdp=None, type_=None):
+    assert ip_server is not None
     assert sdp is not None
     assert type_ is not None
     sdp = webrtc_streaming_pb2.SDP(sdp=sdp, type=type_)
