@@ -2,7 +2,7 @@ import socketio
 from webrtc_streaming.negotiate import negotiate
 
 
-def start(signalig_server, secret_key):
+def start(signalig_server, webrtc_streaming_server, secret_key):
     sio = socketio.Client()
 
     @sio.event
@@ -17,7 +17,7 @@ def start(signalig_server, secret_key):
         print("Server ask for offer to viewer " + viewer_id)
         sdp = remote_description["sdp"]
         type_ = remote_description["type"]
-        answer = negotiate(sdp=sdp, type_=type_)
+        answer = negotiate(ip_server=webrtc_streaming_server, sdp=sdp, type_=type_)
         sio.emit("offer_to_viewer", {"viewer_id": viewer_id, "offer": answer})
 
     @sio.event
