@@ -7,11 +7,12 @@ from webrtc_streaming.autogen import (
 )
 
 
-def update_frame(ip_server="localhost:50051",
+def update_frame(ip_server=None,
                  data=None,
                  width=None,
                  height=None):
     try:
+        assert ip_server is not None
         assert data is not None
         assert isinstance(width, int)
         assert isinstance(height, int)
@@ -20,6 +21,6 @@ def update_frame(ip_server="localhost:50051",
         channel = grpc.insecure_channel(ip_server)
         stub = webrtc_streaming_pb2_grpc.WebRTC_StreamingStub(channel)
         response = stub.UpdateFrame(frame)
-        return isinstance(response, webrtc_streaming_pb2.Empty())
+        return isinstance(response, webrtc_streaming_pb2.Empty)
     except Exception:
         return False
